@@ -6,10 +6,8 @@
 //
 
 #include <stdlib.h>
-#include <kconfig.h>
-#include <kapp.h>
-#include <kglobal.h>
-#include <kstddirs.h>
+#include <kapplication.h>
+#include <kstandarddirs.h>
 #include "amoranim.h"
 #include "amorpm.h"
 
