@@ -5,14 +5,11 @@
 // Copyright (c) 1999 Martin R. Jones <mjones@kde.org>
 //
 
-#include <qlayout.h>
-#include <qpushbutton.h>
 #include <qcheckbox.h>
 #include <qlabel.h>
 #include <qslider.h>
-#include <qdir.h>
 #include <qpainter.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <ksimpleconfig.h>
 
 #include "amordialog.h"
@@ -20,8 +17,7 @@
 #include "version.h"
 #include <klocale.h>
 #include <qvbox.h>
-#include <kglobal.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 
 //---------------------------------------------------------------------------
 //
