@@ -10,8 +10,8 @@
 
 #include <qdialog.h>
 #include <qlistbox.h>
-#include <qlist.h>
-#include <qmultilinedit.h>
+#include <qptrlist.h>
+#include <qmultilineedit.h>
 #include "amorconfig.h"
 #include <kdialogbase.h>
 
