@@ -1,11 +1,9 @@
-
 #include "config.h"
 
 #include <time.h>
 #include <stdlib.h>
 
 
-#include <qtimer.h>
 #include <qdatetime.h>
 
 
@@ -16,11 +14,12 @@
 #include <kcolordialog.h>
 #include <kconfig.h>
 
-
+#include <qcursor.h>
 #include <qpainter.h>
 #include <qpopupmenu.h>
 #include <qregexp.h>
 #include <qiconset.h>
+#include <qtooltip.h>
 
 
 #include "cities.h"
@@ -49,6 +48,7 @@ MapWidget::MapWidget(bool applet, bool restore, QWidget *parent, const char *nam
 
   setBackgroundMode(QWidget::NoBackground);
   
+  gmt_position = 0;
   time_t t = time(NULL);
   setTime(gmtime(&t));
 
@@ -103,19 +103,26 @@ MapWidget::MapWidget(bool applet, bool restore, QWidget *parent, const char *nam
     }
 
   _popup->insertSeparator();
-  _popup->insertItem(i18n("&About..."), this, SLOT(about()));
+  _popup->insertItem(i18n("&About"), this, SLOT(about()));
 
   QTimer *timer = new QTimer(this);
   connect(timer, SIGNAL(timeout()), this, SLOT(timeout()));
   timer->start(1000);
 
-  _cityIndicator = new QLabel(0,0, WStyle_Customize | WStyle_NoBorder | WStyle_Tool );
+  _cityIndicator = new QLabel(0,0, WStyle_StaysOnTop | WStyle_Customize | WStyle_NoBorder | WStyle_Tool | WX11BypassWM );
+  _cityIndicator->setMargin(1);
+  _cityIndicator->setIndent(0);
+  _cityIndicator->setAutoMask(false);
+  _cityIndicator->setLineWidth(1);
+  _cityIndicator->setAlignment(QLabel::AlignAuto | QLabel::AlignTop);
   _cityIndicator->setAutoResize(true);
   _cityIndicator->setFrameStyle(QFrame::Box | QFrame::Plain);
-  _cityIndicator->setBackgroundMode(PaletteBase);
+  _cityIndicator->setPalette(QToolTip::palette());
 
   if (restore && !applet)
     load(kapp->config());
+    
+  connect(&m_timer, SIGNAL(timeout()), this, SLOT(updateCityIndicator()));
 }
 
 
@@ -228,7 +235,10 @@ void MapWidget::setCities(bool c)
 
   setMouseTracking(c);
   if (!c)
+  {
     _cityIndicator->hide();
+    m_timer.stop();
+  }
     
   update();  
 }
@@ -297,7 +307,7 @@ void MapWidget::timeout()
 
 QString MapWidget::cityTime(QString city)
 {
-  QString result = city;
+  QString result = i18n(city.latin1()); // Time zone translation
   int pos = result.find("/");
   if (pos >= 0)
     result = result.mid(pos+1);
@@ -320,15 +330,13 @@ QString MapWidget::cityTime(QString city)
 
 void MapWidget::enterEvent(QEvent *)
 {
-  if ( _cities && !_currentCity.isEmpty())
-    _cityIndicator->show();
-  _cityIndicator->raise();
-}
- 
+  updateCityIndicator();
+} 
  
 void MapWidget::leaveEvent(QEvent *)
 {
   _cityIndicator->hide();
+  m_timer.stop();
 }
 
 
@@ -357,19 +365,25 @@ void MapWidget::mousePressEvent(QMouseEvent *ev)
 } 
 
 
-void MapWidget::mouseMoveEvent(QMouseEvent *ev)
+void MapWidget::mouseMoveEvent(QMouseEvent *)
 {
   if (!_cities)
     return;
 
+  if (!m_timer.isActive())
+     m_timer.start(25, true);
+}
+
+void MapWidget::updateCityIndicator()
+{
   QPoint where;
-  City *c = _cityList->getNearestCity(width(), height(), gmt_position, ev->x(), ev->y(), where);
+  QPoint pos = mapFromGlobal(QCursor::pos());
+  City *c = _cityList->getNearestCity(width(), height(), gmt_position, pos.x(), pos.y(), where);
 
   if (c)
     {
       _currentCity = c->name();
-      showIndicator(ev->globalPos());
-      _cityIndicator->show();
+      showIndicator(QCursor::pos());
     }
   else
     _cityIndicator->hide();
@@ -417,11 +431,14 @@ void MapWidget::setTime(struct tm *time)
 {
   sec = time->tm_hour*60*60 + time->tm_min*60 + time->tm_sec;
   
-  int old_position = gmt_position;
-  gmt_position = width() * sec / 86400; // note: greenwich is in the middle!
+  if (isVisible())
+  {
+     int old_position = gmt_position;
+     gmt_position = width() * sec / 86400; // note: greenwich is in the middle!
   
-  if (old_position != gmt_position)
-    updateBackground();
+     if (old_position != gmt_position)
+        updateBackground();
+  }
 }
 
 
